/***************************************************************
 * Name:      wx011Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-30
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx011Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx011Frame, wxFrame)
    EVT_CLOSE(wx011Frame::OnClose)
    EVT_MENU(idMenuQuit, wx011Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx011Frame::OnAbout)
    EVT_MENU(idMenuScroll, wx011Frame::OnScroll)
END_EVENT_TABLE()

wx011Frame::wx011Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title), dataScroll(0, 100, 0, 60)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuScroll, _T("S&croll"), _T("Ejemplo de Scroll"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}

wx011Frame::~wx011Frame()
{
}

void wx011Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx011Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx011Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Bienvenido a ..."));
}

void wx011Frame::OnScroll(wxCommandEvent& event)
{
    wxString cad;
    scroll *dlg = new scroll(this, dataScroll);
    dlg->ShowModal();

    cad << "H: " << dataScroll.horizontal << " V: " << dataScroll.vertical;
    wxMessageBox(cad, _T("Respuesta"));
}
